# Calculate co-effecienct of Variance

### Instructions

1. Install:

        pip install get-cov2


2. Calculate the co-effecient of variance

        from get_cov_2 import main
        # calculate the co-effecient of variance
        cov = main.get_cov(series).cov()
